@@ -1,7 +1,7 @@
 """
 Type annotations for sts service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
+[Open documentation](./client.md)
 
 Usage::
 
@@ -16,7 +16,7 @@ from typing import Any, Dict, List, Type
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_sts.type_defs import (
+from .type_defs import (
     AssumeRoleResponseTypeDef,
     AssumeRoleWithSAMLResponseTypeDef,
     AssumeRoleWithWebIdentityResponseTypeDef,
@@ -54,8 +54,8 @@ class Exceptions:
 
 class STSClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client)
+    [Show boto3-stubs documentation](./client.md)
     """
 
     meta: ClientMeta
@@ -76,8 +76,8 @@ class STSClient:
         SourceIdentity: str = None,
     ) -> AssumeRoleResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.assume_role)
+        [Show boto3-stubs documentation](./client.md#assume_role)
         """
 
     def assume_role_with_saml(
@@ -90,8 +90,8 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithSAMLResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role_with_saml)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role-with-saml)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.assume_role_with_saml)
+        [Show boto3-stubs documentation](./client.md#assume_role_with_saml)
         """
 
     def assume_role_with_web_identity(
@@ -105,22 +105,22 @@ class STSClient:
         DurationSeconds: int = None,
     ) -> AssumeRoleWithWebIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#assume-role-with-web-identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.assume_role_with_web_identity)
+        [Show boto3-stubs documentation](./client.md#assume_role_with_web_identity)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def decode_authorization_message(
         self, EncodedMessage: str
     ) -> DecodeAuthorizationMessageResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.decode_authorization_message)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#decode-authorization-message)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.decode_authorization_message)
+        [Show boto3-stubs documentation](./client.md#decode_authorization_message)
         """
 
     def generate_presigned_url(
@@ -131,20 +131,20 @@ class STSClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_access_key_info(self, AccessKeyId: str) -> GetAccessKeyInfoResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_access_key_info)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-access-key-info)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.get_access_key_info)
+        [Show boto3-stubs documentation](./client.md#get_access_key_info)
         """
 
     def get_caller_identity(self) -> GetCallerIdentityResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_caller_identity)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-caller-identity)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.get_caller_identity)
+        [Show boto3-stubs documentation](./client.md#get_caller_identity)
         """
 
     def get_federation_token(
@@ -156,14 +156,14 @@ class STSClient:
         Tags: List[TagTypeDef] = None,
     ) -> GetFederationTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_federation_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-federation-token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.get_federation_token)
+        [Show boto3-stubs documentation](./client.md#get_federation_token)
         """
 
     def get_session_token(
         self, DurationSeconds: int = None, SerialNumber: str = None, TokenCode: str = None
     ) -> GetSessionTokenResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.70/reference/services/sts.html#STS.Client.get_session_token)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sts/client.html#get-session-token)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.72/reference/services/sts.html#STS.Client.get_session_token)
+        [Show boto3-stubs documentation](./client.md#get_session_token)
         """
